# Contributing Guide

Thank you for being interested in contributing to the `quantecon-book-theme`! You
are awesome ✨.

This project follows the QuantEcon [contribution guidelines](https://quantecon.org/en/latest/contributing.html).
It contains information about our conventions around coding style, pull request workflow, commit messages and more.

The rest of these sections contain information about developing the `quantecon-book-theme` specifically.

```{toctree}
:maxdepth: 2
:caption: Contributing Guide
setup
architecture
testing
```
